summaryrefslogtreecommitdiff
path: root/gtk/gtktextbuffer.h
diff options
context:
space:
mode:
authorAlexander Larsson <alexl@redhat.com>2020-02-06 16:33:34 +0100
committerAlexander Larsson <alexl@redhat.com>2020-02-06 17:47:56 +0100
commit828269820183c6f6a8fc553bfd1387d110f3ae02 (patch)
tree77591b43b95930aa5fb99a7f7611389c90b2c672 /gtk/gtktextbuffer.h
parentfcc3c1291970f115315e24a9281ad3ac94388a12 (diff)
downloadgtk+-828269820183c6f6a8fc553bfd1387d110f3ae02.tar.gz
textview: Use paintables instead of textures, and fix the support
This changes gtk_text_buffer_insert_texture() to gtk_text_buffer_insert_paintable() which is strictly more useful (as textures are paintables). It also fixes the code to actually support drawing the paintables (as well as tracking changes to the paintables.
Diffstat (limited to 'gtk/gtktextbuffer.h')
-rw-r--r--gtk/gtktextbuffer.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/gtk/gtktextbuffer.h b/gtk/gtktextbuffer.h
index 969db7f3d8..a844d94f5b 100644
--- a/gtk/gtktextbuffer.h
+++ b/gtk/gtktextbuffer.h
@@ -85,7 +85,7 @@ struct _GtkTextBuffer
* GtkTextBufferClass:
* @parent_class: The object class structure needs to be the first.
* @insert_text: The class handler for the #GtkTextBuffer::insert-text signal.
* @insert_texture: The class handler for the #GtkTextBuffer::insert-texture signal.
* @insert_child_anchor: The class handler for the #GtkTextBuffer::insert-child-anchor signal.
* @delete_range: The class handler for the #GtkTextBuffer::delete-range signal.
* @changed: The class handler for the #GtkTextBuffer::changed signal.
@@ -107,9 +107,9 @@ struct _GtkTextBufferClass
const gchar *new_text,
gint new_text_length);
- void (* insert_texture) (GtkTextBuffer *buffer,
+ void (* insert_paintable) (GtkTextBuffer *buffer,
GtkTextIter *iter,
- GdkTexture *texture);
+ GdkPaintable *paintable);
void (* insert_child_anchor) (GtkTextBuffer *buffer,
GtkTextIter *iter,
@@ -267,11 +267,11 @@ gchar *gtk_text_buffer_get_slice (GtkTextBuffer *buffer,
const GtkTextIter *end,
gboolean include_hidden_chars);
-/* Insert a texture */
+/* Insert a paintable */
GDK_AVAILABLE_IN_ALL
-void gtk_text_buffer_insert_texture (GtkTextBuffer *buffer,
+void gtk_text_buffer_insert_paintable (GtkTextBuffer *buffer,
GtkTextIter *iter,
- GdkTexture *texture);
+ GdkPaintable *texture);
/* Insert a child anchor */
GDK_AVAILABLE_IN_ALL
@@ -85,7 +85,7 @@ struct _GtkTextBuffer
* @parent_class: The object class structure needs to be the first.
* @insert_text: The class handler for the #GtkTextBuffer::insert-text signal.
- * @insert_texture: The class handler for the #GtkTextBuffer::insert-texture signal.
+ * @insert_paintable: The class handler for the #GtkTextBuffer::insert-paintable signal.
* @insert_child_anchor: The class handler for the #GtkTextBuffer::insert-child-anchor signal.
* @delete_range: The class handler for the #GtkTextBuffer::delete-range signal.